# fastapi-auth
SDK for integrating your Python FastAPI application with Wristband. Handles user authentication and token management.


1. Build package
```bash
poetry build
```
2. Set token 
```bash
poetry config pypi-token.pypi <your-token>
```